==> validio_sdk-0.7.0.tar.gz: validio_sdk-0.7.0/validio_sdk/exception.py <==
"""Exceptions used throughout the system."""
from typing import Any


class ValidioError(Exception):
    """Base exception used for every exception thrown by Validio."""

    def __init__(self, *args: Any):
        """Construct the exception."""
        super().__init__(*args)


class ConfigNotFoundError(ValidioError):
    """Exception when no configuration is found."""

    def __init__(
        self, endpoint_env: str, access_key_env: str, secret_access_key_env: str
    ) -> None:
        """Construct the exception."""
        super().__init__(
            "No configuration file found. Run 'validio config init' to create one or"
            f" set the environment variables '{endpoint_env}',"
            f" '{access_key_env}' and '{secret_access_key_env}'"
        )


class ConfigInvalidError(ValidioError):
    """Exception when the configuration file is invalid."""

    def __init__(self) -> None:
        """Construct the exception."""
        super().__init__("Configuration file is invalid.")


class UnauthorizedError(ValidioError):
    """Exception thrown when unauthorized request is made."""

    def __init__(self, access_key_env: str, secret_access_key_env: str) -> None:
        """Construct the exception."""
        super().__init__(
            "🛑 Unauthorized!\n"
            "Make sure you have proper credentials and run 'validio config init' to"
            f" add them or use '{access_key_env}' and"
            f" '{secret_access_key_env}'"
        )


class ValidioConnectionError(ValidioError):
    """Exception thrown when connection to Validio backend fails."""

    def __init__(self, endpoint_env: str, e: Exception) -> None:
        """Construct the exception."""
        super().__init__(
            f"🛑 Failed to connect to server: {str(e)}\n"
            "Check your network environment, run 'validio config init' to set a proper"
            f" server endpoint or use '{endpoint_env}'"
        )

==> validio_sdk-0.18.1.tar.gz: validio_sdk-0.18.1/validio_sdk/exception.py <==
"""Exceptions used throughout the system."""

import json
from typing import Any

from validio_sdk.graphql_client.exceptions import GraphQLClientHttpError


class ValidioError(Exception):
    """Base exception used for every exception thrown by Validio."""

    def __init__(self, *args: Any):
        """Construct the exception."""
        super().__init__(*args)


class ValidioBugError(ValidioError):
    """Same as `ValidioError` but marked for bugs to be reported."""

    def __init__(self, *args: Any):
        """Construct the exception."""
        super().__init__(*args)

    def __str__(self) -> str:
        """String representation for the exception."""
        s = f"{super().__str__()}\n"
        s += "This is a bug, please report to support@validio.io"

        return s


class ValidioGraphQLError(ValidioError):
    """A `ValidioError` that wraps a GraphQL error."""

    def __init__(self, error: GraphQLClientHttpError, context: str | None = None):
        """Construct the exception."""
        super().__init__()
        self.context = context
        self.gql_error = error

    def __str__(self) -> str:
        """String representation for the exception."""
        try:
            response = self.gql_error.response.json()
        except json.decoder.JSONDecodeError:
            response = self.gql_error.response.text

        s = f"{self.context}\n\n" if self.context else ""
        s += f"HTTP status code: {self.gql_error.response.status_code}\n"
        s += f"HTTP response: {response}"

        return s


class ConfigNotFoundError(ValidioError):
    """Exception when no configuration is found."""

    def __init__(
        self, endpoint_env: str, access_key_env: str, secret_access_key_env: str
    ) -> None:
        """Construct the exception."""
        super().__init__(
            "No configuration file found. Run 'validio config init' to create one or"
            f" set the environment variables '{endpoint_env}',"
            f" '{access_key_env}' and '{secret_access_key_env}'"
        )


class ConfigInvalidError(ValidioError):
    """Exception when the configuration file is invalid."""

    def __init__(self) -> None:
        """Construct the exception."""
        super().__init__("Configuration file is invalid.")


class UnauthorizedError(ValidioError):
    """Exception thrown when unauthorized request is made."""

    def __init__(self, access_key_env: str, secret_access_key_env: str) -> None:
        """Construct the exception."""
        super().__init__(
            "🛑 Unauthorized!\n"
            "Make sure you have proper credentials and run 'validio config init' to"
            f" add them or use '{access_key_env}' and"
            f" '{secret_access_key_env}'"
        )


class ValidioConnectionError(ValidioError):
    """Exception thrown when connection to Validio backend fails."""

    def __init__(self, endpoint_env: str, e: Exception) -> None:
        """Construct the exception."""
        super().__init__(
            f"🛑 Failed to connect to server: {e!s}\n"
            "Check your network environment, run 'validio config init' to set a proper"
            f" server endpoint or use '{endpoint_env}'"
        )
